OppiaMobile Server Change Log — OppiaMobile 0.7.1 documentation

# OppiaMobile Server Change Log

## v0.7.2 - not yet released

- https://github.com/DigitalCampus/django-oppia/issues/issue/220 - update course list display

## v0.7.1 - released 18 Feb 2015

- https://github.com/DigitalCampus/django-oppia/issues/issue/170 - publishing directly via API

## v0.7.0 - released 11 Feb 2015

- https://github.com/DigitalCampus/django-oppia/issues/issue/213 - reset password using email address
- https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/117 - add support for Moodle url activities
- https://github.com/DigitalCampus/django-oppia/issues/issue/141 - remove course download model
- https://github.com/DigitalCampus/django-oppia/issues/issue/129 - visualisation menu update
- https://github.com/DigitalCampus/django-oppia/issues/issue/215 - add course manager model

## v0.6.0 - released 22 Dec 2014

- https://github.com/DigitalCampus/django-oppia/issues/211 - save phone no on register via API
- https://github.com/DigitalCampus/django-oppia/issues/212 - Fix quiz titles

## Previous Versions

- OppiaMobile Server Change Log for v0.5.x
  - v0.5.3 - released: 20 Dec 2014
  - v0.5.2 - released: 26 Oct 2014
  - v0.5.1 - released: 30 Sept 2014
- Change Log for v0.4.x
  - v0.4.4 - released: 18-Aug-2014
  - v0.4.3 - released: 18-Jul-2014
  - v0.4.2 - released: 2-Jul-2014
  - v0.4.1 - released: 27-May-2014
  - v0.4.0 - released: 1-Apr-2014
- Change Log for v0.3.x
  - v0.3.0 - released: 30 Mar 2014
- Change Log for v0.2.x
  - v0.2.15 - 21-Mar-2014
  - v0.2.14 - 20-Mar-2014
  - v0.2.12/13 - 18-Mar-2014
  - v0.2.10/11 - 17-Mar-2014
  - v0.2.8/9 - 17-Mar-2014
  - v0.2.7 - 14-Mar-2014
  - v0.2.6 - 8-Mar-2014
  - v0.2.5 - 4-Mar-2014
  - v0.2.1
  - v0.2.0
- Change Log for v0.1.x
  - v0.1.40
  - v0.1.39
  - v0.1.38
  - v0.1.37
  - v0.1.35
  - v0.1.34
  - v0.1.33
  - v0.1.32
  - v0.1.31
  - v0.1.30
  - v0.1.29
  - v0.1.28
  - v0.1.26
  - v0.1.23
  - v0.1.22
  - v0.1.21
  - v0.1.20
  - v0.1.19
  - v0.1.18
  - v0.1.17
  - v0.1.16
  - v0.1.15
  - v0.1.14
  - v0.1.13
  - v0.1.12